Learn R Programming

deepspat (version 0.3.1)

bisquares1D: Bisquare functions on a 1D domain

Description

Sets up a top-layer set of bisquare basis functions on a bounded 1D domain of length 1 for modelling the process \(Y\). It returns a list of length 1 containing the basis functions and encapsulated functions that evaluate the bisquare functions over inputs of different types. See Value for more details.

Usage

bisquares1D(r = 30, lims = c(-0.5, 0.5), dtype = "float32")

Value

bisquares1D returns a list containing a list with the following components:

"f"

An encapsulated function that takes an input and evaluates the sigmoids over the dim-th dimension using TensorFlow

"r"

The number of sigmoid basis functions

"knots_tf"

The centroids of the basis functions as a TensorFlow object

Arguments

r

30

lims

the limits of one side of the square bounded 2D domain on which to set up the bisquare functions

dtype

data type