Learn R Programming

deepspat (version 0.3.1)

bisquares2D: Bisquare functions on a 2D domain

Description

Sets up a top-layer set of bisquare basis functions on a square 2D domain of size 1 x 1 for modelling the process \(Y\). It returns a list of length 1 containing the basis functions and encapsulated functions that evaluate the bisquare functions over inputs of different types. See Value for more details.

Usage

bisquares2D(r = 30, lims = c(-0.5, 0.5), dtype = "float32")

Value

bisquares1D returns a list containing a list with the following components:

"f"

An encapsulated function that takes an input and evaluates the sigmoids over the dim-th dimension using TensorFlow

"fR"

Same as f but uses R

"r"

The number of sigmoid basis functions

"knots_tf"

The centroids of the basis functions as a TensorFlow object

"knots"

The centroids of the basis functions as an R object

Arguments

r

30

lims

the bounded 1D domain on which to set up the bisquare functions

dtype

data type