Constructs a deep compositional spatial model (with nearest neighbors)
deepspat_nn_GP(
f,
data,
g = ~1,
layers = NULL,
m = 25L,
order_id,
nn_id,
method = c("REML"),
family = c("exp_stat", "exp_nonstat"),
par_init = initvars(),
learn_rates = init_learn_rates(),
nsteps = 150L
)deepspat_nn_GP returns an object of class deepspat_nn_GP with the following items
The formula used to construct the covariance model
The formula used to construct the linear trend model
The data used to construct the deepspat model
The model matrix of the linear trend
The warping function layers in the model
The final value of the cost
Estimated weights in the warping layers as a list of TensorFlow objects
Estimated parameters in the LFT layers
Estimated coefficients of the linear trend
Precision of measurement error, as a TensorFlow object
Variance parameter in the covariance matrix, as a TensorFlow object
Length scale parameter in the covariance matrix, as a TensorFlow object
Minima and maxima used to scale the unscaled unit outputs for each warping layer, as a list of TensorFlow objects
Method used for inference
Number of warping layers in the model
Spatial locations on the warped domain
Vector of costs after each gradient-descent evaluation
Data of the process
The number of nearest neighbors
Family of the model
formula identifying the dependent variables and the spatial inputs in the covariance
data frame containing the required data
formula identifying the independent variables in the linear trend
list containing the nonstationary warping layers
number of nearest neighbors
indices of the order of the observations
indices of the nearest neighbors of the ordered observations
identifying the method for finding the estimates
identifying the family of the model constructed
list of initial parameter values. Call the function initvars() to see the structure of the list
learning rates for the various quantities in the model. Call the function init_learn_rates() to see the structure of the list
number of steps when doing gradient descent times two or three (depending on the family of model)