Learn R Programming

deepspat (version 0.3.1)

deepspat_nn_ST_GP: Deep compositional spatio-temporal model (with nearest neighbors) for Gaussian processes

Description

Constructs a deep compositional spatio-temporal model (with nearest neighbors)

Usage

deepspat_nn_ST_GP(
  f,
  data,
  g = ~1,
  layers_spat = NULL,
  layers_temp = NULL,
  m = 25L,
  order_id,
  nn_id,
  method = c("REML"),
  family = c("exp_stat_sep", "exp_stat_asym", "exp_nonstat_sep", "exp_nonstat_asym"),
  par_init = initvars(),
  learn_rates = init_learn_rates(),
  nsteps = 150L
)

Value

deepspat_nn_ST_GP returns an object of class deepspat_nn_ST_GP with the following items

"f"

The formula used to construct the covariance model

"g"

The formula used to construct the linear trend model

"data"

The data used to construct the deepspat model

"X"

The model matrix of the linear trend

"layers_spat"

The spatial warping function layers in the model

"layers_temp"

The temporal warping function layers in the model

"Cost"

The final value of the cost

"family"

Family of the model

"eta_tf"

Estimated weights in the spatial warping layers as a list of TensorFlow objects

"eta_t_tf"

Estimated weights in the temporal warping layers as a list of TensorFlow objects

"a_tf"

Estimated parameters in the LFT layers

"beta"

Estimated coefficients of the linear trend

"precy_tf"

Precision of measurement error, as a TensorFlow object

"sigma2_tf"

Variance parameter in the covariance matrix, as a TensorFlow object

"v_tf"

Parameters of the covariance matrix (indicating asymmetric spatio-temporal covariance)

"l_tf"

Length scale (for spatial dimension) parameter in the covariance matrix, as a TensorFlow object

"l_t_tf"

Length scale (for temporal dimension) parameter in the covariance matrix, as a TensorFlow object

"scalings"

Minima and maxima used to scale the unscaled unit outputs for each spatial warping layer, as a list of TensorFlow objects

"scalings_t"

Minima and maxima used to scale the unscaled unit outputs for each temporal warping layer, as a list of TensorFlow objects

"method"

Method used for inference

"nlayers_spat"

Number of spatial warping layers in the model

"nlayers_temp"

Number of temporal warping layers in the model

"swarped_tf"

Spatial locations on the warped domain

"twarped_tf"

Temporal locations on the warped domain

"negcost"

Vector of costs after each gradient-descent evaluation

"z_tf"

Data of the process

"m"

The number of nearest neighbors

Arguments

f

formula identifying the dependent variables and the spatial inputs in the covariance

data

data frame containing the required data

g

formula identifying the independent variables in the linear trend

layers_spat

list containing the spatial warping layers

layers_temp

list containing the temporal warping layers

m

number of nearest neighbors

order_id

indices of the order of the observations

nn_id

indices of the nearest neighbors of the ordered observations

method

identifying the method for finding the estimates

family

identifying the family of the model constructed

par_init

list of initial parameter values. Call the function initvars() to see the structure of the list

learn_rates

learning rates for the various quantities in the model. Call the function init_learn_rates() to see the structure of the list

nsteps

number of steps when doing gradient descent times two or three (depending on the family of model)