Learn R Programming

deepspat (version 0.3.1)

deepspat_trivar_GP: Deep trivariate compositional spatial model for Gaussian processes

Description

Constructs a deep trivariate compositional spatial model

Usage

deepspat_trivar_GP(
  f,
  data,
  g = ~1,
  layers_asym_2 = NULL,
  layers_asym_3 = NULL,
  layers = NULL,
  method = c("REML"),
  family = c("matern_stat_symm", "matern_stat_asymm", "matern_nonstat_symm",
    "matern_nonstat_asymm"),
  par_init = initvars(),
  learn_rates = init_learn_rates(),
  nsteps = 150L
)

Value

deepspat_trivar_GP returns an object of class deepspat_trivar_GP with the following items

"f"

The formula used to construct the covariance model

"g"

The formula used to construct the linear trend model

"data"

The data used to construct the deepspat model

"X"

The model matrix of the linear trend

"layers"

The warping function layers in the model

"layers_asym_2"

The aligning function layers for the second process in the model

"layers_asym_3"

The aligning function layers for the third process in the model

"Cost"

The final value of the cost

"eta_tf"

Estimated weights in the warping layers as a list of TensorFlow objects

"eta_tf_asym_2"

Estimated weights in the aligning layers for the second process as a list of TensorFlow objects

"eta_tf_asym_3"

Estimated weights in the aligning layers for the third process as a list of TensorFlow objects

"beta"

Estimated coefficients of the linear trend

"precy_tf1"

Precision of measurement error of the first process, as a TensorFlow object

"precy_tf2"

Precision of measurement error of the second process, as a TensorFlow object

"precy_tf3"

Precision of measurement error of the third process, as a TensorFlow object

"sigma2_tf_1"

Variance parameter (first process) in the covariance matrix, as a TensorFlow object

"sigma2_tf_2"

Variance parameter (second process) in the covariance matrix, as a TensorFlow object

"sigma2_tf_3"

Variance parameter (third process) in the covariance matrix, as a TensorFlow object

"sigma2_tf_12"

Covariance parameter (between first and second process) in the covariance matrix, as a TensorFlow object

"sigma2_tf_13"

Covariance parameter (between first and third process) in the covariance matrix, as a TensorFlow object

"sigma2_tf_23"

Covariance parameter (between second and third process) in the covariance matrix, as a TensorFlow object

"l_tf1"

Length scale parameter (first process) in the covariance matrix, as a TensorFlow object

"l_tf2"

Length scale parameter (second process) in the covariance matrix, as a TensorFlow object

"l_tf3"

Length scale parameter (third process) in the covariance matrix, as a TensorFlow object

"l_tf12"

Length scale parameter (cross-covariance between first and second process) in the covariance matrix, as a TensorFlow object

"l_tf13"

Length scale parameter (cross-covariance between first and third process) in the covariance matrix, as a TensorFlow object

"l_tf23"

Length scale parameter (cross-covariance between second and third process) in the covariance matrix, as a TensorFlow object

"nu_tf1"

Smoothness parameter (first process) in the covariance matrix, as a TensorFlow object

"nu_tf2"

Smoothness parameter (second process) in the covariance matrix, as a TensorFlow object

"nu_tf3"

Smoothness parameter (third process) in the covariance matrix, as a TensorFlow object

"nu_tf12"

Smoothness parameter (cross-covariance between first and second process) in the covariance matrix, as a TensorFlow object

"nu_tf13"

Smoothness parameter (cross-covariance between first and third process) in the covariance matrix, as a TensorFlow object

"nu_tf23"

Smoothness parameter (cross-covariance between second and third process) in the covariance matrix, as a TensorFlow object

"scalings"

Minima and maxima used to scale the unscaled unit outputs for each warping layer, as a list of TensorFlow objects

"scalings_asym"

Minima and maxima used to scale the unscaled unit outputs for each aligning layer, as a list of TensorFlow objects

"method"

Method used for inference

"nlayers"

Number of warping layers in the model

"nlayers_asym"

Number of aligning layers in the model

"run"

TensorFlow session for evaluating the TensorFlow objects

"swarped_tf1"

Spatial locations of the first process on the warped domain

"swarped_tf2"

Spatial locations of the second process on the warped domain

"swarped_tf3"

Spatial locations of the third process on the warped domain

"negcost"

Vector of costs after each gradient-descent evaluation

"z_tf_1"

Data of the first process

"z_tf_2"

Data of the second process

"z_tf_3"

Data of the third process

"family"

Family of the model

Arguments

f

formula identifying the dependent variables and the spatial inputs in the covariance

data

data frame containing the required data

g

formula identifying the independent variables in the linear trend

layers_asym_2

list containing the aligning function layers for the second process

layers_asym_3

list containing the aligning function layers for the third process

layers

list containing the nonstationary warping layers

method

identifying the method for finding the estimates

family

identifying the family of the model constructed

par_init

list of initial parameter values. Call the function initvars() to see the structure of the list

learn_rates

learning rates for the various quantities in the model. Call the function init_learn_rates() to see the structure of the list

nsteps

number of steps when doing gradient descent times two, three or five (depending on the family of model)