Sets up a top-layer set of bisquare basis functions on a bounded 1D domain of length 1 for modelling the process \(Y\). It returns a list of length 1 containing the basis functions and encapsulated functions that evaluate the bisquare functions over inputs of different types. See Value for more details.
bisquares1D(r = 30, lims = c(-0.5, 0.5), dtype = "float32")bisquares1D returns a list containing a list with the following components:
An encapsulated function that takes an input and evaluates the sigmoids over the dim-th dimension using TensorFlow
The number of sigmoid basis functions
The centroids of the basis functions as a TensorFlow object
30
the limits of one side of the square bounded 2D domain on which to set up the bisquare functions
data type