Sets up a top-layer set of bisquare basis functions on a square 2D domain of size 1 x 1 for modelling the process \(Y\). It returns a list of length 1 containing the basis functions and encapsulated functions that evaluate the bisquare functions over inputs of different types. See Value for more details.
bisquares2D(r = 30, lims = c(-0.5, 0.5), dtype = "float32")bisquares1D returns a list containing a list with the following components:
An encapsulated function that takes an input and evaluates the sigmoids over the dim-th dimension using TensorFlow
Same as f but uses R
The number of sigmoid basis functions
The centroids of the basis functions as a TensorFlow object
The centroids of the basis functions as an R object
30
the bounded 1D domain on which to set up the bisquare functions
data type