- "f"
The formula used to construct the covariance model
- "g"
The formula used to construct the linear trend model
- "data"
The data used to construct the deepspat model
- "X"
The model matrix of the linear trend
- "layers"
The warping function layers in the model
- "layers_asym"
The aligning function layers in the model
- "Cost"
The final value of the cost
- "eta_tf"
Estimated weights in the warping layers as a list of TensorFlow objects
- "eta_tf_asym"
Estimated weights in the aligning layers as a list of TensorFlow objects
- "a_tf"
Estimated parameters in the LFT layers
- "a_tf_asym"
Estimated parameters in the AFF layers of the aligning function
- "beta"
Estimated coefficients of the linear trend
- "precy_tf1"
Precision of measurement error of the first process, as a TensorFlow object
- "precy_tf2"
Precision of measurement error of the second process, as a TensorFlow object
- "sigma2_tf_1"
Variance parameter (first process) in the covariance matrix, as a TensorFlow object
- "sigma2_tf_2"
Variance parameter (second process) in the covariance matrix, as a TensorFlow object
- "sigma2_tf_12"
Covariance parameter in the covariance matrix, as a TensorFlow object
- "l_tf1"
Length scale parameter (first process) in the covariance matrix, as a TensorFlow object
- "l_tf2"
Length scale parameter (second process) in the covariance matrix, as a TensorFlow object
- "l_tf12"
Length scale parameter (cross-covariance) in the covariance matrix, as a TensorFlow object
- "nu_tf1"
Smoothness parameter (first process) in the covariance matrix, as a TensorFlow object
- "nu_tf2"
Smoothness parameter (second process) in the covariance matrix, as a TensorFlow object
- "nu_tf12"
Smoothness parameter (cross-covariance) in the covariance matrix, as a TensorFlow object
- "scalings"
Minima and maxima used to scale the unscaled unit outputs for each warping layer, as a list of TensorFlow objects
- "scalings_asym"
Minima and maxima used to scale the unscaled unit outputs for each aligning layer, as a list of TensorFlow objects
- "method"
Method used for inference
- "nlayers"
Number of warping layers in the model
- "nlayers_asym"
Number of aligning layers in the model
- "swarped_tf1"
Spatial locations of the first process on the warped domain
- "swarped_tf2"
Spatial locations of the second process on the warped domain
- "negcost"
Vector of costs after each gradient-descent evaluation
- "z_tf_1"
Data of the first process
- "z_tf_2"
Data of the second process
- "family"
Family of the model