Constructs a deep trivariate compositional spatial model
deepspat_trivar_GP(
f,
data,
g = ~1,
layers_asym_2 = NULL,
layers_asym_3 = NULL,
layers = NULL,
method = c("REML"),
family = c("matern_stat_symm", "matern_stat_asymm", "matern_nonstat_symm",
"matern_nonstat_asymm"),
par_init = initvars(),
learn_rates = init_learn_rates(),
nsteps = 150L
)deepspat_trivar_GP returns an object of class deepspat_trivar_GP with the following items
The formula used to construct the covariance model
The formula used to construct the linear trend model
The data used to construct the deepspat model
The model matrix of the linear trend
The warping function layers in the model
The aligning function layers for the second process in the model
The aligning function layers for the third process in the model
The final value of the cost
Estimated weights in the warping layers as a list of TensorFlow objects
Estimated weights in the aligning layers for the second process as a list of TensorFlow objects
Estimated weights in the aligning layers for the third process as a list of TensorFlow objects
Estimated coefficients of the linear trend
Precision of measurement error of the first process, as a TensorFlow object
Precision of measurement error of the second process, as a TensorFlow object
Precision of measurement error of the third process, as a TensorFlow object
Variance parameter (first process) in the covariance matrix, as a TensorFlow object
Variance parameter (second process) in the covariance matrix, as a TensorFlow object
Variance parameter (third process) in the covariance matrix, as a TensorFlow object
Covariance parameter (between first and second process) in the covariance matrix, as a TensorFlow object
Covariance parameter (between first and third process) in the covariance matrix, as a TensorFlow object
Covariance parameter (between second and third process) in the covariance matrix, as a TensorFlow object
Length scale parameter (first process) in the covariance matrix, as a TensorFlow object
Length scale parameter (second process) in the covariance matrix, as a TensorFlow object
Length scale parameter (third process) in the covariance matrix, as a TensorFlow object
Length scale parameter (cross-covariance between first and second process) in the covariance matrix, as a TensorFlow object
Length scale parameter (cross-covariance between first and third process) in the covariance matrix, as a TensorFlow object
Length scale parameter (cross-covariance between second and third process) in the covariance matrix, as a TensorFlow object
Smoothness parameter (first process) in the covariance matrix, as a TensorFlow object
Smoothness parameter (second process) in the covariance matrix, as a TensorFlow object
Smoothness parameter (third process) in the covariance matrix, as a TensorFlow object
Smoothness parameter (cross-covariance between first and second process) in the covariance matrix, as a TensorFlow object
Smoothness parameter (cross-covariance between first and third process) in the covariance matrix, as a TensorFlow object
Smoothness parameter (cross-covariance between second and third process) in the covariance matrix, as a TensorFlow object
Minima and maxima used to scale the unscaled unit outputs for each warping layer, as a list of TensorFlow objects
Minima and maxima used to scale the unscaled unit outputs for each aligning layer, as a list of TensorFlow objects
Method used for inference
Number of warping layers in the model
Number of aligning layers in the model
TensorFlow session for evaluating the TensorFlow objects
Spatial locations of the first process on the warped domain
Spatial locations of the second process on the warped domain
Spatial locations of the third process on the warped domain
Vector of costs after each gradient-descent evaluation
Data of the first process
Data of the second process
Data of the third process
Family of the model
formula identifying the dependent variables and the spatial inputs in the covariance
data frame containing the required data
formula identifying the independent variables in the linear trend
list containing the aligning function layers for the second process
list containing the aligning function layers for the third process
list containing the nonstationary warping layers
identifying the method for finding the estimates
identifying the family of the model constructed
list of initial parameter values. Call the function initvars() to see the structure of the list
learning rates for the various quantities in the model. Call the function init_learn_rates() to see the structure of the list
number of steps when doing gradient descent times two, three or five (depending on the family of model)